@@ -200,7 +200,7 @@ public abstract class ResourceController {
     }
 
 	/** register defaults in freeplane.properties respectively defaults.properties instead. */
-	public long getLongProperty(final String key, final int defaultValue) {
+	public long getLongProperty(final String key, final long defaultValue) {
 		try {
 			return Long.parseLong(getProperty(key));
 		}
@@ -282,6 +282,10 @@ public abstract class ResourceController {
 		setProperty(name, Integer.toString(value));
 	}
 
+	public void setProperty(String name, long value) {
+		setProperty(name, Long.toString(value));
+	}
+
 	abstract public void setProperty(final String property, final String value);
 	
 	/** adds properties from url to properties. Existing properties in resultProps will be overridden.
