@@ -730,12 +730,13 @@ public class MLinkController extends LinkController {
 	}
 
 	private URI relativeLink(final URI argUri, final NodeModel node, final int linkType) {
-		if (linkType != LINK_ABSOLUTE && "file".equals(argUri.getScheme())) {
+		if (linkType == LINK_RELATIVE_TO_MINDMAP && "file".equals(argUri.getScheme())) {
 			try {
 				final File mapFile = node.getMap().getFile();
-				return LinkController.toRelativeURI(mapFile, new File(argUri), linkType);
+				return createRelativeURI(mapFile, argUri);
 			}
 			catch (Exception e) {
+				e.printStackTrace();
 			}
 		}
 		return argUri;
