@@ -28,6 +28,7 @@ import java.awt.event.KeyEvent;
 import java.io.File;
 import java.io.IOException;
 import java.lang.reflect.InvocationTargetException;
+import java.net.URL;
 import java.util.Collections;
 import java.util.Set;
 
@@ -76,6 +77,9 @@ import org.freeplane.features.ui.FrameController;
 import org.freeplane.features.url.mindmapmode.MFileManager;
 import org.freeplane.main.addons.AddOnsController;
 import org.freeplane.main.application.CommandLineParser.Options;
+import org.freeplane.main.application.survey.FreeplaneSurveyProperties;
+import org.freeplane.main.application.survey.SurveyRunner;
+import org.freeplane.main.application.survey.SurveyStarter;
 import org.freeplane.main.browsemode.BModeControllerFactory;
 import org.freeplane.main.filemode.FModeControllerFactory;
 import org.freeplane.main.mindmapmode.MModeControllerFactory;
@@ -213,6 +217,10 @@ public class FreeplaneGUIStarter implements FreeplaneStarter {
 			    new LogicalStyleFilterController());
 			MapController.install();
 			NodeHistory.install(controller);
+			final FreeplaneSurveyProperties freeplaneSurveyProperties = new FreeplaneSurveyProperties();
+			if(freeplaneSurveyProperties.mayAskUserToFillSurveys()) {
+				controller.addApplicationLifecycleListener(new SurveyStarter(freeplaneSurveyProperties, new SurveyRunner(freeplaneSurveyProperties), Math.random()));
+			}
 			return controller;
 		}
 		catch (final Exception e) {
@@ -295,10 +303,8 @@ public class FreeplaneGUIStarter implements FreeplaneStarter {
 		});
 	}
 
-	protected void fireStartupFinished() {
-		for (ApplicationLifecycleListener listener : Controller.getCurrentController().getApplicationLifecycleListeners()) {
-			listener.onStartupFinished();
-		}
+	private void fireStartupFinished() {
+		Controller.getCurrentController().fireStartupFinished();
 	}
 
 	private void loadMaps( final String[] args) {
