@@ -25,6 +25,7 @@ import java.awt.Graphics;
 import java.awt.Image;
 import java.awt.image.BufferedImage;
 import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.ref.WeakReference;
@@ -227,7 +228,7 @@ public class BitmapViewerComponent extends JComponent implements ScalableCompone
 			cachedImage = ImageIO.read(cacheFile);
 		}
 		catch (final IOException e) {
-			LogUtils.severe("ImageIO can not read cache file " + cacheFile , e);
+			logImageReadingException(e);
 		}
 	}
 
@@ -260,11 +261,19 @@ public class BitmapViewerComponent extends JComponent implements ScalableCompone
 			tempImage = ImageIO.read(url);
 		}
 		catch (final IOException e) {
-			LogUtils.severe(e);
+			logImageReadingException(e);
 		}
 		return tempImage;
 	}
 
+	private void logImageReadingException(final IOException e) {
+		final Throwable cause = e.getCause();
+		if(! (cause instanceof FileNotFoundException))
+			LogUtils.severe(e);
+		else
+			LogUtils.warn(cause.getMessage());
+	}
+
 	private void flushImage() {
 		final CacheType cacheType = getCacheType();
 		if (CacheType.IC_RAM.equals(cacheType)) {
