@@ -173,15 +173,21 @@ fi
 # enable this in order to turn off the splash screen:
 #JAVA_OPTS="-Dorg.freeplane.nosplash=true $JAVA_OPTS"
 
+# grant all permissions to shared java extension libs if available
+if [ -d "/usr/share/java" ] ; then
+	JAVA_OPTS="-Dorg.freeplane.os.lib.ext=/usr/share/java $JAVA_OPTS"
+fi
+
 _debug "Calling: "\
 "${JAVACMD}" -Xmx512m\
  "-Dorg.freeplane.userfpdir=$userfpdir"\
  "-Dorg.freeplane.old_userfpdir=$old_userfpdir"\
  "-Dorg.freeplane.globalresourcedir=${freedir}/resources"\
+ "-Dswing.systemlaf=javax.swing.plaf.metal.MetalLookAndFeel"\
  $JAVA_OPTS\
  $xdockname\
  -jar "${freedir}/freeplanelauncher.jar"\
- $*
+ "$@"
 ( echo "${DEBUG}" | grep -qe "exit" ) && exit 0 # do not start Freeplane
 
 # now actually launch Freeplane
@@ -189,7 +195,8 @@ _debug "Calling: "\
  "-Dorg.freeplane.userfpdir=$userfpdir"\
  "-Dorg.freeplane.old_userfpdir=$old_userfpdir"\
  "-Dorg.freeplane.globalresourcedir=${freedir}/resources"\
+ "-Dswing.systemlaf=javax.swing.plaf.metal.MetalLookAndFeel"\
  $JAVA_OPTS\
  $xdockname\
  -jar "${freedir}/freeplanelauncher.jar"\
- $*
+ "$@"
